@@ -2,7 +2,7 @@ from typing import Optional, Sequence, List, Set, Callable
 
 
 class CasedModel:
-    title: Optional[str] = None
+    title: str
     flexible_case: bool = True
     case_lower_func: Callable[[str], str] = lambda x: x.lower()
     case_title_func: Callable[[str], str] = lambda x: x.title()
@@ -11,17 +11,17 @@ class CasedModel:
     def __post_init__(self):
         super().__init__()
 
-    def to_title_case_str(self) -> Optional[str]:
+    def to_title_case_str(self) -> str:
         if not self.flexible_case:
             return self.title
         return self.case_title_func(self.title)  # type: ignore
 
-    def to_lower_case_str(self) -> Optional[str]:
+    def to_lower_case_str(self) -> str:
         if not self.flexible_case:
             return self.title
         return self.case_lower_func(self.title)  # type: ignore
 
-    def to_capitalized_str(self) -> Optional[str]:
+    def to_capitalized_str(self) -> str:
         if not self.flexible_case:
             return self.title
         return self.case_capitalize_func(self.title)  # type: ignore
