@@ -147,6 +147,144 @@ OCC_MARKET_RAD = Organization(
 )
 
 OCC_MARKET_RAD_TARGET = ApplicationTarget(OCC_MARKET_RAD, 'Financial Economist')
+OCC_MARKET_RAD_USAJOBS_TARGET = ApplicationTarget(OCC_MARKET_RAD, 'Financial Economist', custom_app_name='OCC Market RAD USAJOBS')
+
+def get_occ_market_rad_usajobs_cv_model(model: CVModel) -> CVModel:
+    def modify_uf_description(desc: Sequence[str]) -> Sequence[str]:
+        new_first_point = """
+Independently conduct full economics and finance research projects, including planning, information assembly, 
+analysis and evaluation, conclusions and report preparation.
+Submit papers for publication in peer-reviewed journal articles. Topics include analyses of banking legislation
+and regulations, and assessments of significant trends and developments in financial markets
+        """.strip()
+        extra_begin_point = """
+Apply finance, econometrics, economics, mathematics, and statistics theories and methods to develop 
+quantitative or statistical models to assess the impact of financial developments on the economy
+        """.strip()
+        extra_begin_point2 = """
+Apply analytical and research techniques including econometrics, mathematical economics, 
+and cost-benefit analyses
+        """.strip()
+        extra_end_point = """
+Evaluate impacts of economic policies and propose policy ideas, working in research teams and independently
+        """.strip()
+        extra_end_point2 = """
+Develop analytical tools and publish them as open-source packages
+        """.strip()
+        extra_end_point3 = """
+Develop comprehensive reports reflecting analysis, conclusions, and recommendations, and present 
+such findings to faculty and students
+        """.strip()
+        extra_end_point4 = """
+Implement quantitative analyses and data collection/management in Python, SAS, Stata, MATLAB, and R
+        """.strip()
+        extra_end_point5 = """
+Independently develop and teach courses relating to economics subjects including financial markets, modeling, and banking.
+Create presentation slides, problem sets, examples, and projects. Present slides and examples 
+to students for class instruction in person and virtually. Grade problems sets and projects and provide feedback
+to students. Guide selected students through personal research to produce evidence of results.
+        """
+        extra_end_point6 = """
+Utilize economic and financial data sets including CRSP, Compustat, OptionMetrics, OPRA, TAQ, Ravenpack,
+Cryptocompare, FRED, IBES, Datastream, EIKON, and Morningstar  
+        """.strip()
+        new_desc = [
+            new_first_point,
+            extra_begin_point,
+            extra_begin_point2,
+            *desc[1:],
+            extra_end_point,
+            extra_end_point2,
+            extra_end_point3,
+            extra_end_point4,
+            extra_end_point5,
+            extra_end_point6,
+        ]
+        return new_desc
+
+    def modify_evb_description(desc: Sequence[str]) -> Sequence[str]:
+        extra_begin_point = """
+Conduct bank-specific quantitative analyses relating to financial risks, using quantitative models 
+to evaluate the use of capital
+        """.strip()
+        new_first_point = """
+Analyze and model bank commercial credit risk by forecasting credit losses, determining how much capital is required 
+to meet regulatory requirements, through rebuilding the Allowance for Loan and Lease Losses (ALLL) models, 
+ultimately saving \$5.4 million for the bank
+        """.strip()
+        new_second_point = """
+Developed credit risk metrics such as probability of default (PD) and loss given default (LGD) for 
+over 10,000 commercial
+and consumer loans by internal risk grade, delinquency status, and FFIEC code using migration analysis
+        """.strip()
+        new_third_point = """
+Evaluate operational and model risk by developing a stress testing framework
+        """.strip()
+        extra_end_point = """
+Analyze the conditions of the banking industry to understand competitors' capitalization relating 
+to regulatory requirements
+        """.strip()
+        extra_end_point2 = """
+Provide advice and keep management informed about issues relating to bank capitalization 
+via comprehensive reports, narratives, and briefings reflecting analysis, 
+conclusions, and recommendations
+        """.strip()
+        new_desc = [
+            extra_begin_point,
+            new_first_point,
+            new_second_point,
+            new_third_point,
+            extra_end_point,
+            extra_end_point2,
+        ]
+        return new_desc
+
+    def modify_fed_description(desc: Sequence[str]) -> Sequence[str]:
+        extra_begin_point = """
+Support projects that respond to requests by senior management for materials
+on a variety of topics including policy and management issues confronting the Fed,
+analyses of banking legislation and regulations, and assessments of 
+significant trends and developments in the banking industry
+        """.strip()
+        new_begin_point = """
+Analyzed the market of banking institutions to understand their assessments of risk, 
+to prepare reports and briefings and develop a standardized risk scale
+        """.strip()
+        new_end_point = """
+Contribute to the collection, analysis, and interpretation of Shared National Credit (SNC) 
+data, to respond to inquiries that affect the banking system and financial markets
+        """
+        return [
+            extra_begin_point,
+            new_begin_point,
+            new_end_point
+        ]
+
+    model.modify_job_descriptions = {
+        JobIDs.UF_GA: modify_uf_description,
+        JobIDs.EVB_PORTFOLIO_ANALYST: modify_evb_description,
+        JobIDs.FRB_INTERN: modify_fed_description,
+    }
+
+    app_info: Dict[str, str] = {
+        'Job Announcement Number': 'DH-HQ-TL-20-2212',
+        'Job Title': 'Financial Economist',
+        'Grade Level(s)': 'NB V2',
+        'Location(s)': 'Washington, DC',
+        'Full Legal Name': 'Nicholas Andrew DeRobertis',
+        'US Citizen': 'Yes'
+    }
+    model.application_info = app_info
+
+    model.include_hours_per_week = True
+
+    model.font_scale = 0.85
+    model.line_spacing = 0.85
+
+    model.sections.insert(6, ResumeSection.CONTINUED)
+    model.sections.insert(5, ResumeSection.CONTINUED)
+
+    return model
 
 OCC_CCRAD = Organization(
     'Office of the Comptroller of the Currency',
